

%this function takes a 2D slice of the FFT of 4D light field
% Inverse 2D FFT of the slice gives the refocused image

% See Ren Ng, 'Fourier Slice Photography', SIGGRAPH 2005 for techical
% details

% Key Idea: A 2D image is a slice of 4D light field in Fourier Domain

function IOut = Refocus2D(FFTLF,theta)


[m,n,p,q] = size(FFTLF);
Theta1 = theta(1);
Theta2 = theta(2);

cTem = floor(size(FFTLF)/2)  +   1;


% find the coordinates of 2D slice
[XX,YY] = meshgrid(1:n,1:m);
cc = (XX - cTem(2))/size(FFTLF,2);
cc = Theta2*cc + cTem(4);
dd = (YY - cTem(1))/size(FFTLF,1);
dd = Theta1*dd + cTem(3);

% Resample 4D light field along the 2D slice
v = interpn(FFTLF,YY,XX,dd,cc,'cubic');

%set nan values to zero
idx = find(isnan(v)==1);
disp(sprintf('Number of Nans in sampling = %d',size(idx,1)))
v(isnan(v)) =   0;

% take inverse 2D FFT to get the image
IOut = real(ifft2(ifftshift(v)));






